@@ -425,6 +425,8 @@ class GringoClasp(GringoClaspBase):
 
     def run_print(self, programs, printer, nmodels = 1, additionalProgramText=None):
         assert(programs.__class__ == list)
+        collapseTerms=False
+        collapseAtoms=False
         # options need to be filtered to work with Popen
         # since gringo/clasp doesn't like whitespace before numbers parameter
         try:
@@ -470,7 +472,7 @@ class GringoClasp(GringoClaspBase):
         l = self._clasp.stdout.readline()
         #f = self._clasp.stderr.readline()
         #print f,'f'
-        parser = Parser(collapseTerms=True,collapseAtoms=True)
+        parser = Parser(collapseTerms=collapseTerms,collapseAtoms=collapseAtoms)
         count=0
         while l != '':
 
